summaryrefslogtreecommitdiffstats
path: root/pyload/plugin/hook
diff options
context:
space:
mode:
Diffstat (limited to 'pyload/plugin/hook')
-rw-r--r--pyload/plugin/hook/AlldebridCom.py14
-rw-r--r--pyload/plugin/hook/BypassCaptcha.py22
-rw-r--r--pyload/plugin/hook/Captcha9Kw.py14
-rw-r--r--pyload/plugin/hook/CaptchaBrotherhood.py18
-rw-r--r--pyload/plugin/hook/DeathByCaptcha.py18
-rw-r--r--pyload/plugin/hook/DebridItaliaCom.py14
-rw-r--r--pyload/plugin/hook/EasybytezCom.py14
-rw-r--r--pyload/plugin/hook/ExpertDecoders.py14
-rw-r--r--pyload/plugin/hook/FastixRu.py14
-rw-r--r--pyload/plugin/hook/FreeWayMe.py14
-rw-r--r--pyload/plugin/hook/ImageTyperz.py20
-rw-r--r--pyload/plugin/hook/LinkdecrypterCom.py14
-rw-r--r--pyload/plugin/hook/LinksnappyCom.py14
-rw-r--r--pyload/plugin/hook/MegaDebridEu.py14
-rw-r--r--pyload/plugin/hook/MultihostersCom.py14
-rw-r--r--pyload/plugin/hook/MultishareCz.py14
-rw-r--r--pyload/plugin/hook/MyfastfileCom.py14
-rw-r--r--pyload/plugin/hook/NoPremiumPl.py14
-rw-r--r--pyload/plugin/hook/OverLoadMe.py14
-rw-r--r--pyload/plugin/hook/PremiumTo.py14
-rw-r--r--pyload/plugin/hook/PremiumizeMe.py14
-rw-r--r--pyload/plugin/hook/PutdriveCom.py14
-rw-r--r--pyload/plugin/hook/RPNetBiz.py14
-rw-r--r--pyload/plugin/hook/RapideoPl.py14
-rw-r--r--pyload/plugin/hook/RealdebridCom.py14
-rw-r--r--pyload/plugin/hook/RehostTo.py14
-rw-r--r--pyload/plugin/hook/SimplyPremiumCom.py14
-rw-r--r--pyload/plugin/hook/SimplydebridCom.py14
-rw-r--r--pyload/plugin/hook/SmoozedCom.py14
-rw-r--r--pyload/plugin/hook/UnrestrictLi.py14
-rw-r--r--pyload/plugin/hook/XFileSharingPro.py16
-rw-r--r--pyload/plugin/hook/ZeveraCom.py14
32 files changed, 236 insertions, 236 deletions
diff --git a/pyload/plugin/hook/AlldebridCom.py b/pyload/plugin/hook/AlldebridCom.py
index abd270e93..6d3e5db48 100644
--- a/pyload/plugin/hook/AlldebridCom.py
+++ b/pyload/plugin/hook/AlldebridCom.py
@@ -4,11 +4,11 @@ from pyload.plugin.internal.MultiHook import MultiHook
class AlldebridCom(MultiHook):
- __name = "AlldebridCom"
- __type = "hook"
- __version = "0.16"
+ __name__ = "AlldebridCom"
+ __type__ = "hook"
+ __version__ = "0.16"
- __config = [("pluginmode" , "all;listed;unlisted", "Use for plugins" , "all"),
+ __config__ = [("pluginmode" , "all;listed;unlisted", "Use for plugins" , "all"),
("pluginlist" , "str" , "Plugin list (comma separated)" , "" ),
("revertfailed" , "bool" , "Revert to standard download if fails", True ),
("retry" , "int" , "Number of retries before revert" , 10 ),
@@ -17,9 +17,9 @@ class AlldebridCom(MultiHook):
("reloadinterval", "int" , "Reload interval in hours" , 12 ),
("ssl" , "bool" , "Use HTTPS" , True )]
- __description = """Alldebrid.com hook plugin"""
- __license = "GPLv3"
- __authors = [("Andy Voigt", "spamsales@online.de")]
+ __description__ = """Alldebrid.com hook plugin"""
+ __license__ = "GPLv3"
+ __authors__ = [("Andy Voigt", "spamsales@online.de")]
def getHosters(self):
diff --git a/pyload/plugin/hook/BypassCaptcha.py b/pyload/plugin/hook/BypassCaptcha.py
index 2aba60999..7b7e156bb 100644
--- a/pyload/plugin/hook/BypassCaptcha.py
+++ b/pyload/plugin/hook/BypassCaptcha.py
@@ -26,16 +26,16 @@ class BypassCaptchaException(Exception):
class BypassCaptcha(Hook):
- __name = "BypassCaptcha"
- __type = "hook"
- __version = "0.06"
+ __name__ = "BypassCaptcha"
+ __type__ = "hook"
+ __version__ = "0.06"
- __config = [("force", "bool", "Force BC even if client is connected", False),
+ __config__ = [("force", "bool", "Force BC even if client is connected", False),
("passkey", "password", "Passkey", "")]
- __description = """Send captchas to BypassCaptcha.com"""
- __license = "GPLv3"
- __authors = [("RaNaN", "RaNaN@pyload.org"),
+ __description__ = """Send captchas to BypassCaptcha.com"""
+ __license__ = "GPLv3"
+ __authors__ = [("RaNaN", "RaNaN@pyload.org"),
("Godofdream", "soilfcition@gmail.com"),
("zoidberg", "zoidberg@mujmail.cz")]
@@ -104,21 +104,21 @@ class BypassCaptcha(Hook):
if self.getCredits() > 0:
task.handler.append(self)
- task.data['service'] = self.__name
+ task.data['service'] = self.__name__
task.setWaiting(100)
self._processCaptcha(task)
else:
- self.logInfo(_("Your %s account has not enough credits") % self.__name)
+ self.logInfo(_("Your %s account has not enough credits") % self.__name__)
def captchaCorrect(self, task):
- if task.data['service'] == self.__name and "ticket" in task.data:
+ if task.data['service'] == self.__name__ and "ticket" in task.data:
self.respond(task.data['ticket'], True)
def captchaInvalid(self, task):
- if task.data['service'] == self.__name and "ticket" in task.data:
+ if task.data['service'] == self.__name__ and "ticket" in task.data:
self.respond(task.data['ticket'], False)
diff --git a/pyload/plugin/hook/Captcha9Kw.py b/pyload/plugin/hook/Captcha9Kw.py
index 88b9f58e7..dd3fb1ba1 100644
--- a/pyload/plugin/hook/Captcha9Kw.py
+++ b/pyload/plugin/hook/Captcha9Kw.py
@@ -14,11 +14,11 @@ from pyload.plugin.Hook import Hook, threaded
class Captcha9kw(Hook):
- __name = "Captcha9Kw"
- __type = "hook"
- __version = "0.28"
+ __name__ = "Captcha9Kw"
+ __type__ = "hook"
+ __version__ = "0.28"
- __config = [("ssl" , "bool" , "Use HTTPS" , True ),
+ __config__ = [("ssl" , "bool" , "Use HTTPS" , True ),
("force" , "bool" , "Force captcha resolving even if client is connected" , True ),
("confirm" , "bool" , "Confirm Captcha (cost +6 credits)" , False ),
("captchaperhour", "int" , "Captcha per hour" , "9999" ),
@@ -30,9 +30,9 @@ class Captcha9kw(Hook):
("passkey" , "password", "API key" , "" ),
("timeout" , "int" , "Timeout in seconds (min 60, max 3999)" , "900" )]
- __description = """Send captchas to 9kw.eu"""
- __license = "GPLv3"
- __authors = [("RaNaN", "RaNaN@pyload.org"),
+ __description__ = """Send captchas to 9kw.eu"""
+ __license__ = "GPLv3"
+ __authors__ = [("RaNaN", "RaNaN@pyload.org"),
("Walter Purcaro", "vuolter@gmail.com")]
diff --git a/pyload/plugin/hook/CaptchaBrotherhood.py b/pyload/plugin/hook/CaptchaBrotherhood.py
index b854602b9..554d102ec 100644
--- a/pyload/plugin/hook/CaptchaBrotherhood.py
+++ b/pyload/plugin/hook/CaptchaBrotherhood.py
@@ -36,17 +36,17 @@ class CaptchaBrotherhoodException(Exception):
class CaptchaBrotherhood(Hook):
- __name = "CaptchaBrotherhood"
- __type = "hook"
- __version = "0.08"
+ __name__ = "CaptchaBrotherhood"
+ __type__ = "hook"
+ __version__ = "0.08"
- __config = [("username", "str", "Username", ""),
+ __config__ = [("username", "str", "Username", ""),
("force", "bool", "Force CT even if client is connected", False),
("passkey", "password", "Password", "")]
- __description = """Send captchas to CaptchaBrotherhood.com"""
- __license = "GPLv3"
- __authors = [("RaNaN", "RaNaN@pyload.org"),
+ __description__ = """Send captchas to CaptchaBrotherhood.com"""
+ __license__ = "GPLv3"
+ __authors__ = [("RaNaN", "RaNaN@pyload.org"),
("zoidberg", "zoidberg@mujmail.cz")]
@@ -142,7 +142,7 @@ class CaptchaBrotherhood(Hook):
if self.getCredits() > 10:
task.handler.append(self)
- task.data['service'] = self.__name
+ task.data['service'] = self.__name__
task.setWaiting(100)
self._processCaptcha(task)
else:
@@ -150,7 +150,7 @@ class CaptchaBrotherhood(Hook):
def captchaInvalid(self, task):
- if task.data['service'] == self.__name and "ticket" in task.data:
+ if task.data['service'] == self.__name__ and "ticket" in task.data:
res = self.api_response("complainCaptcha", task.data['ticket'])
diff --git a/pyload/plugin/hook/DeathByCaptcha.py b/pyload/plugin/hook/DeathByCaptcha.py
index 47101194e..e0108963b 100644
--- a/pyload/plugin/hook/DeathByCaptcha.py
+++ b/pyload/plugin/hook/DeathByCaptcha.py
@@ -49,17 +49,17 @@ class DeathByCaptchaException(Exception):
class DeathByCaptcha(Hook):
- __name = "DeathByCaptcha"
- __type = "hook"
- __version = "0.06"
+ __name__ = "DeathByCaptcha"
+ __type__ = "hook"
+ __version__ = "0.06"
- __config = [("username", "str", "Username", ""),
+ __config__ = [("username", "str", "Username", ""),
("passkey", "password", "Password", ""),
("force", "bool", "Force DBC even if client is connected", False)]
- __description = """Send captchas to DeathByCaptcha.com"""
- __license = "GPLv3"
- __authors = [("RaNaN", "RaNaN@pyload.org"),
+ __description__ = """Send captchas to DeathByCaptcha.com"""
+ __license__ = "GPLv3"
+ __authors__ = [("RaNaN", "RaNaN@pyload.org"),
("zoidberg", "zoidberg@mujmail.cz")]
@@ -183,13 +183,13 @@ class DeathByCaptcha(Hook):
if balance > rate:
task.handler.append(self)
- task.data['service'] = self.__name
+ task.data['service'] = self.__name__
task.setWaiting(180)
self._processCaptcha(task)
def captchaInvalid(self, task):
- if task.data['service'] == self.__name and "ticket" in task.data:
+ if task.data['service'] == self.__name__ and "ticket" in task.data:
try:
res = self.api_response("captcha/%d/report" % task.data['ticket'], True)
diff --git a/pyload/plugin/hook/DebridItaliaCom.py b/pyload/plugin/hook/DebridItaliaCom.py
index ff5a3aaef..e2f766d86 100644
--- a/pyload/plugin/hook/DebridItaliaCom.py
+++ b/pyload/plugin/hook/DebridItaliaCom.py
@@ -6,11 +6,11 @@ from pyload.plugin.internal.MultiHook import MultiHook
class DebridItaliaCom(MultiHook):
- __name = "DebridItaliaCom"
- __type = "hook"
- __version = "0.12"
+ __name__ = "DebridItaliaCom"
+ __type__ = "hook"
+ __version__ = "0.12"
- __config = [("pluginmode" , "all;listed;unlisted", "Use for plugins" , "all"),
+ __config__ = [("pluginmode" , "all;listed;unlisted", "Use for plugins" , "all"),
("pluginlist" , "str" , "Plugin list (comma separated)" , "" ),
("revertfailed" , "bool" , "Revert to standard download if fails", True ),
("retry" , "int" , "Number of retries before revert" , 10 ),
@@ -18,9 +18,9 @@ class DebridItaliaCom(MultiHook):
("reload" , "bool" , "Reload plugin list" , True ),
("reloadinterval", "int" , "Reload interval in hours" , 12 )]
- __description = """Debriditalia.com hook plugin"""
- __license = "GPLv3"
- __authors = [("stickell", "l.stickell@yahoo.it"),
+ __description__ = """Debriditalia.com hook plugin"""
+ __license__ = "GPLv3"
+ __authors__ = [("stickell", "l.stickell@yahoo.it"),
("Walter Purcaro", "vuolter@gmail.com")]
diff --git a/pyload/plugin/hook/EasybytezCom.py b/pyload/plugin/hook/EasybytezCom.py
index 7d934fd22..1163bbf46 100644
--- a/pyload/plugin/hook/EasybytezCom.py
+++ b/pyload/plugin/hook/EasybytezCom.py
@@ -6,11 +6,11 @@ from pyload.plugin.internal.MultiHook import MultiHook
class EasybytezCom(MultiHook):
- __name = "EasybytezCom"
- __type = "hook"
- __version = "0.07"
+ __name__ = "EasybytezCom"
+ __type__ = "hook"
+ __version__ = "0.07"
- __config = [("pluginmode" , "all;listed;unlisted", "Use for plugins" , "all"),
+ __config__ = [("pluginmode" , "all;listed;unlisted", "Use for plugins" , "all"),
("pluginlist" , "str" , "Plugin list (comma separated)" , "" ),
("revertfailed" , "bool" , "Revert to standard download if fails", True ),
("retry" , "int" , "Number of retries before revert" , 10 ),
@@ -18,9 +18,9 @@ class EasybytezCom(MultiHook):
("reload" , "bool" , "Reload plugin list" , True ),
("reloadinterval", "int" , "Reload interval in hours" , 12 )]
- __description = """EasyBytez.com hook plugin"""
- __license = "GPLv3"
- __authors = [("zoidberg", "zoidberg@mujmail.cz")]
+ __description__ = """EasyBytez.com hook plugin"""
+ __license__ = "GPLv3"
+ __authors__ = [("zoidberg", "zoidberg@mujmail.cz")]
def getHosters(self):
diff --git a/pyload/plugin/hook/ExpertDecoders.py b/pyload/plugin/hook/ExpertDecoders.py
index 702955229..8fbc88c80 100644
--- a/pyload/plugin/hook/ExpertDecoders.py
+++ b/pyload/plugin/hook/ExpertDecoders.py
@@ -12,16 +12,16 @@ from pyload.plugin.Hook import Hook, threaded
class ExpertDecoders(Hook):
- __name = "ExpertDecoders"
- __type = "hook"
- __version = "0.04"
+ __name__ = "ExpertDecoders"
+ __type__ = "hook"
+ __version__ = "0.04"
- __config = [("force", "bool", "Force CT even if client is connected", False),
+ __config__ = [("force", "bool", "Force CT even if client is connected", False),
("passkey", "password", "Access key", "")]
- __description = """Send captchas to expertdecoders.com"""
- __license = "GPLv3"
- __authors = [("RaNaN", "RaNaN@pyload.org"),
+ __description__ = """Send captchas to expertdecoders.com"""
+ __license__ = "GPLv3"
+ __authors__ = [("RaNaN", "RaNaN@pyload.org"),
("zoidberg", "zoidberg@mujmail.cz")]
diff --git a/pyload/plugin/hook/FastixRu.py b/pyload/plugin/hook/FastixRu.py
index 0f07d0d84..8bc3b3f16 100644
--- a/pyload/plugin/hook/FastixRu.py
+++ b/pyload/plugin/hook/FastixRu.py
@@ -5,11 +5,11 @@ from pyload.plugin.internal.MultiHook import MultiHook
class FastixRu(MultiHook):
- __name = "FastixRu"
- __type = "hook"
- __version = "0.05"
+ __name__ = "FastixRu"
+ __type__ = "hook"
+ __version__ = "0.05"
- __config = [("pluginmode" , "all;listed;unlisted", "Use for plugins" , "all"),
+ __config__ = [("pluginmode" , "all;listed;unlisted", "Use for plugins" , "all"),
("pluginlist" , "str" , "Plugin list (comma separated)" , "" ),
("revertfailed" , "bool" , "Revert to standard download if fails", True ),
("retry" , "int" , "Number of retries before revert" , 10 ),
@@ -17,9 +17,9 @@ class FastixRu(MultiHook):
("reload" , "bool" , "Reload plugin list" , True ),
("reloadinterval", "int" , "Reload interval in hours" , 12 )]
- __description = """Fastix.ru hook plugin"""
- __license = "GPLv3"
- __authors = [("Massimo Rosamilia", "max@spiritix.eu")]
+ __description__ = """Fastix.ru hook plugin"""
+ __license__ = "GPLv3"
+ __authors__ = [("Massimo Rosamilia", "max@spiritix.eu")]
def getHosters(self):
diff --git a/pyload/plugin/hook/FreeWayMe.py b/pyload/plugin/hook/FreeWayMe.py
index 737cd1e7e..711be37a8 100644
--- a/pyload/plugin/hook/FreeWayMe.py
+++ b/pyload/plugin/hook/FreeWayMe.py
@@ -4,11 +4,11 @@ from pyload.plugin.internal.MultiHook import MultiHook
class FreeWayMe(MultiHook):
- __name = "FreeWayMe"
- __type = "hook"
- __version = "0.14"
+ __name__ = "FreeWayMe"
+ __type__ = "hook"
+ __version__ = "0.14"
- __config = [("pluginmode" , "all;listed;unlisted", "Use for plugins" , "all"),
+ __config__ = [("pluginmode" , "all;listed;unlisted", "Use for plugins" , "all"),
("pluginlist" , "str" , "Plugin list (comma separated)" , "" ),
("revertfailed" , "bool" , "Revert to standard download if fails", True ),
("retry" , "int" , "Number of retries before revert" , 10 ),
@@ -16,9 +16,9 @@ class FreeWayMe(MultiHook):
("reload" , "bool" , "Reload plugin list" , True ),
("reloadinterval", "int" , "Reload interval in hours" , 12 )]
- __description = """FreeWay.me hook plugin"""
- __license = "GPLv3"
- __authors = [("Nicolas Giese", "james@free-way.me")]
+ __description__ = """FreeWay.me hook plugin"""
+ __license__ = "GPLv3"
+ __authors__ = [("Nicolas Giese", "james@free-way.me")]
def getHosters(self):
diff --git a/pyload/plugin/hook/ImageTyperz.py b/pyload/plugin/hook/ImageTyperz.py
index d5a05e209..a9d7326de 100644
--- a/pyload/plugin/hook/ImageTyperz.py
+++ b/pyload/plugin/hook/ImageTyperz.py
@@ -30,17 +30,17 @@ class ImageTyperzException(Exception):
class ImageTyperz(Hook):
- __name = "ImageTyperz"
- __type = "hook"
- __version = "0.06"
+ __name__ = "ImageTyperz"
+ __type__ = "hook"
+ __version__ = "0.06"
- __config = [("username", "str", "Username", ""),
+ __config__ = [("username", "str", "Username", ""),
("passkey", "password", "Password", ""),
("force", "bool", "Force IT even if client is connected", False)]
- __description = """Send captchas to ImageTyperz.com"""
- __license = "GPLv3"
- __authors = [("RaNaN", "RaNaN@pyload.org"),
+ __description__ = """Send captchas to ImageTyperz.com"""
+ __license__ = "GPLv3"
+ __authors__ = [("RaNaN", "RaNaN@pyload.org"),
("zoidberg", "zoidberg@mujmail.cz")]
@@ -118,16 +118,16 @@ class ImageTyperz(Hook):
if self.getCredits() > 0:
task.handler.append(self)
- task.data['service'] = self.__name
+ task.data['service'] = self.__name__
task.setWaiting(100)
self._processCaptcha(task)
else:
- self.logInfo(_("Your %s account has not enough credits") % self.__name)
+ self.logInfo(_("Your %s account has not enough credits") % self.__name__)
def captchaInvalid(self, task):
- if task.data['service'] == self.__name and "ticket" in task.data:
+ if task.data['service'] == self.__name__ and "ticket" in task.data:
res = getURL(self.RESPOND_URL,
post={'action': "SETBADIMAGE",
'username': self.getConfig("username"),
diff --git a/pyload/plugin/hook/LinkdecrypterCom.py b/pyload/plugin/hook/LinkdecrypterCom.py
index fa52cb482..efdf77065 100644
--- a/pyload/plugin/hook/LinkdecrypterCom.py
+++ b/pyload/plugin/hook/LinkdecrypterCom.py
@@ -6,18 +6,18 @@ from pyload.plugin.internal.MultiHook import MultiHook
class LinkdecrypterCom(MultiHook):
- __name = "LinkdecrypterCom"
- __type = "hook"
- __version = "1.02"
+ __name__ = "LinkdecrypterCom"
+ __type__ = "hook"
+ __version__ = "1.02"
- __config = [("pluginmode" , "all;listed;unlisted", "Use for plugins" , "all"),
+ __config__ = [("pluginmode" , "all;listed;unlisted", "Use for plugins" , "all"),
("pluginlist" , "str" , "Plugin list (comma separated)" , "" ),
("reload" , "bool" , "Reload plugin list" , True ),
("reloadinterval", "int" , "Reload interval in hours" , 12 )]
- __description = """Linkdecrypter.com hook plugin"""
- __license = "GPLv3"
- __authors = [("Walter Purcaro", "vuolter@gmail.com")]
+ __description__ = """Linkdecrypter.com hook plugin"""
+ __license__ = "GPLv3"
+ __authors__ = [("Walter Purcaro", "vuolter@gmail.com")]
def getCrypters(self):
diff --git a/pyload/plugin/hook/LinksnappyCom.py b/pyload/plugin/hook/LinksnappyCom.py
index 6a348d85c..dc0c47496 100644
--- a/pyload/plugin/hook/LinksnappyCom.py
+++ b/pyload/plugin/hook/LinksnappyCom.py
@@ -5,11 +5,11 @@ from pyload.plugin.internal.MultiHook import MultiHook
class LinksnappyCom(MultiHook):
- __name = "LinksnappyCom"
- __type = "hook"
- __version = "0.04"
+ __name__ = "LinksnappyCom"
+ __type__ = "hook"
+ __version__ = "0.04"
- __config = [("pluginmode" , "all;listed;unlisted", "Use for plugins" , "all"),
+ __config__ = [("pluginmode" , "all;listed;unlisted", "Use for plugins" , "all"),
("pluginlist" , "str" , "Plugin list (comma separated)" , "" ),
("revertfailed" , "bool" , "Revert to standard download if fails", True ),
("retry" , "int" , "Number of retries before revert" , 10 ),
@@ -17,9 +17,9 @@ class LinksnappyCom(MultiHook):
("reload" , "bool" , "Reload plugin list" , True ),
("reloadinterval", "int" , "Reload interval in hours" , 12 )]
- __description = """Linksnappy.com hook plugin"""
- __license = "GPLv3"
- __authors = [("stickell", "l.stickell@yahoo.it")]
+ __description__ = """Linksnappy.com hook plugin"""
+ __license__ = "GPLv3"
+ __authors__ = [("stickell", "l.stickell@yahoo.it")]
def getHosters(self):
diff --git a/pyload/plugin/hook/MegaDebridEu.py b/pyload/plugin/hook/MegaDebridEu.py
index 8dc6c4f90..7e86d4d49 100644
--- a/pyload/plugin/hook/MegaDebridEu.py
+++ b/pyload/plugin/hook/MegaDebridEu.py
@@ -5,11 +5,11 @@ from pyload.plugin.internal.MultiHook import MultiHook
class MegaDebridEu(MultiHook):
- __name = "MegaDebridEu"
- __type = "hook"
- __version = "0.05"
+ __name__ = "MegaDebridEu"
+ __type__ = "hook"
+ __version__ = "0.05"
- __config = [("pluginmode" , "all;listed;unlisted", "Use for plugins" , "all"),
+ __config__ = [("pluginmode" , "all;listed;unlisted", "Use for plugins" , "all"),
("pluginlist" , "str" , "Plugin list (comma separated)" , "" ),
("revertfailed" , "bool" , "Revert to standard download if fails", True ),
("retry" , "int" , "Number of retries before revert" , 10 ),
@@ -17,9 +17,9 @@ class MegaDebridEu(MultiHook):
("reload" , "bool" , "Reload plugin list" , True ),
("reloadinterval", "int" , "Reload interval in hours" , 12 )]
- __description = """Mega-debrid.eu hook plugin"""
- __license = "GPLv3"
- __authors = [("D.Ducatel", "dducatel@je-geek.fr")]
+ __description__ = """Mega-debrid.eu hook plugin"""
+ __license__ = "GPLv3"
+ __authors__ = [("D.Ducatel", "dducatel@je-geek.fr")]
def getHosters(self):
diff --git a/pyload/plugin/hook/MultihostersCom.py b/pyload/plugin/hook/MultihostersCom.py
index 5cb2396ee..7b92089a1 100644
--- a/pyload/plugin/hook/MultihostersCom.py
+++ b/pyload/plugin/hook/MultihostersCom.py
@@ -4,15 +4,15 @@ from pyload.plugin.hook.ZeveraCom import ZeveraCom
class MultihostersCom(ZeveraCom):
- __name = "MultihostersCom"
- __type = "hook"
- __version = "0.02"
+ __name__ = "MultihostersCom"
+ __type__ = "hook"
+ __version__ = "0.02"
- __config = [("mode" , "all;listed;unlisted", "Use for plugins (if supported)" , "all"),
+ __config__ = [("mode" , "all;listed;unlisted", "Use for plugins (if supported)" , "all"),
("pluginlist" , "str" , "Plugin list (comma separated)" , "" ),
("revertfailed", "bool" , "Revert to standard download if download fails", False),
("interval" , "int" , "Reload interval in hours (0 to disable)" , 12 )]
- __description = """Multihosters.com hook plugin"""
- __license = "GPLv3"
- __authors = [("tjeh", "tjeh@gmx.net")]
+ __description__ = """Multihosters.com hook plugin"""
+ __license__ = "GPLv3"
+ __authors__ = [("tjeh", "tjeh@gmx.net")]
diff --git a/pyload/plugin/hook/MultishareCz.py b/pyload/plugin/hook/MultishareCz.py
index fcfa2371b..56f30fb39 100644
--- a/pyload/plugin/hook/MultishareCz.py
+++ b/pyload/plugin/hook/MultishareCz.py
@@ -6,11 +6,11 @@ from pyload.plugin.internal.MultiHook import MultiHook
class MultishareCz(MultiHook):
- __name = "MultishareCz"
- __type = "hook"
- __version = "0.07"
+ __name__ = "MultishareCz"
+ __type__ = "hook"
+ __version__ = "0.07"
- __config = [("pluginmode" , "all;listed;unlisted", "Use for plugins" , "all"),
+ __config__ = [("pluginmode" , "all;listed;unlisted", "Use for plugins" , "all"),
("pluginlist" , "str" , "Plugin list (comma separated)" , "" ),
("revertfailed" , "bool" , "Revert to standard download if fails", True ),
("retry" , "int" , "Number of retries before revert" , 10 ),
@@ -18,9 +18,9 @@ class MultishareCz(MultiHook):
("reload" , "bool" , "Reload plugin list" , True ),
("reloadinterval", "int" , "Reload interval in hours" , 12 )]
- __description = """MultiShare.cz hook plugin"""
- __license = "GPLv3"
- __authors = [("zoidberg", "zoidberg@mujmail.cz")]
+ __description__ = """MultiShare.cz hook plugin"""
+ __license__ = "GPLv3"
+ __authors__ = [("zoidberg", "zoidberg@mujmail.cz")]
HOSTER_PATTERN = r'<img class="logo-shareserveru"[^>]*?alt="([^"]+)"></td>\s*<td class="stav">[^>]*?alt="OK"'
diff --git a/pyload/plugin/hook/MyfastfileCom.py b/pyload/plugin/hook/MyfastfileCom.py
index 33149dd9c..097a54b60 100644
--- a/pyload/plugin/hook/MyfastfileCom.py
+++ b/pyload/plugin/hook/MyfastfileCom.py
@@ -5,11 +5,11 @@ from pyload.utils import json_loads
class MyfastfileCom(MultiHook):
- __name = "MyfastfileCom"
- __type = "hook"
- __version = "0.05"
+ __name__ = "MyfastfileCom"
+ __type__ = "hook"
+ __version__ = "0.05"
- __config = [("pluginmode" , "all;listed;unlisted", "Use for plugins" , "all"),
+ __config__ = [("pluginmode" , "all;listed;unlisted", "Use for plugins" , "all"),
("pluginlist" , "str" , "Plugin list (comma separated)" , "" ),
("revertfailed" , "bool" , "Revert to standard download if fails", True ),
("retry" , "int" , "Number of retries before revert" , 10 ),
@@ -17,9 +17,9 @@ class MyfastfileCom(MultiHook):
("reload" , "bool" , "Reload plugin list" , True ),
("reloadinterval", "int" , "Reload interval in hours" , 12 )]
- __description = """Myfastfile.com hook plugin"""
- __license = "GPLv3"
- __authors = [("stickell", "l.stickell@yahoo.it")]
+ __description__ = """Myfastfile.com hook plugin"""
+ __license__ = "GPLv3"
+ __authors__ = [("stickell", "l.stickell@yahoo.it")]
def getHosters(self):
diff --git a/pyload/plugin/hook/NoPremiumPl.py b/pyload/plugin/hook/NoPremiumPl.py
index da24a6a99..da7967154 100644
--- a/pyload/plugin/hook/NoPremiumPl.py
+++ b/pyload/plugin/hook/NoPremiumPl.py
@@ -5,11 +5,11 @@ from pyload.plugin.internal.MultiHook import MultiHook
class NoPremiumPl(MultiHook):
- __name = "NoPremiumPl"
- __type = "hook"
- __version = "0.03"
+ __name__ = "NoPremiumPl"
+ __type__ = "hook"
+ __version__ = "0.03"
- __config = [("pluginmode" , "all;listed;unlisted", "Use for plugins" , "all"),
+ __config__ = [("pluginmode" , "all;listed;unlisted", "Use for plugins" , "all"),
("pluginlist" , "str" , "Plugin list (comma separated)" , "" ),
("revertfailed" , "bool" , "Revert to standard download if fails", True ),
("retry" , "int" , "Number of retries before revert" , 10 ),
@@ -17,9 +17,9 @@ class NoPremiumPl(MultiHook):
("reload" , "bool" , "Reload plugin list" , True ),
("reloadinterval", "int" , "Reload interval in hours" , 12 )]
- __description = """NoPremium.pl hook plugin"""
- __license = "GPLv3"
- __authors = [("goddie", "dev@nopremium.pl")]
+ __description__ = """NoPremium.pl hook plugin"""
+ __license__ = "GPLv3"
+ __authors__ = [("goddie", "dev@nopremium.pl")]
def getHosters(self):
diff --git a/pyload/plugin/hook/OverLoadMe.py b/pyload/plugin/hook/OverLoadMe.py
index 9caa19897..e4602019f 100644
--- a/pyload/plugin/hook/OverLoadMe.py
+++ b/pyload/plugin/hook/OverLoadMe.py
@@ -4,11 +4,11 @@ from pyload.plugin.internal.MultiHook import MultiHook
class OverLoadMe(MultiHook):
- __name = "OverLoadMe"
- __type = "hook"
- __version = "0.04"
+ __name__ = "OverLoadMe"
+ __type__ = "hook"
+ __version__ = "0.04"
- __config = [("pluginmode" , "all;listed;unlisted", "Use for plugins" , "all"),
+ __config__ = [("pluginmode" , "all;listed;unlisted", "Use for plugins" , "all"),
("pluginlist" , "str" , "Plugin list (comma separated)" , "" ),
("revertfailed" , "bool" , "Revert to standard download if fails", True ),
("retry" , "int" , "Number of retries before revert" , 10 ),
@@ -17,9 +17,9 @@ class OverLoadMe(MultiHook):
("reloadinterval", "int" , "Reload interval in hours" , 12 ),
("ssl" , "bool" , "Use HTTPS" , True )]
- __description = """Over-Load.me hook plugin"""
- __license = "GPLv3"
- __authors = [("marley", "marley@over-load.me")]
+ __description__ = """Over-Load.me hook plugin"""
+ __license__ = "GPLv3"
+ __authors__ = [("marley", "marley@over-load.me")]
def getHosters(self):
diff --git a/pyload/plugin/hook/PremiumTo.py b/pyload/plugin/hook/PremiumTo.py
index 353d10ebd..58d753cec 100644
--- a/pyload/plugin/hook/PremiumTo.py
+++ b/pyload/plugin/hook/PremiumTo.py
@@ -4,11 +4,11 @@ from pyload.plugin.internal.MultiHook import MultiHook
class PremiumTo(MultiHook):
- __name = "PremiumTo"
- __type = "hook"
- __version = "0.08"
+ __name__ = "PremiumTo"
+ __type__ = "hook"
+ __version__ = "0.08"
- __config = [("pluginmode" , "all;listed;unlisted", "Use for plugins" , "all"),
+ __config__ = [("pluginmode" , "all;listed;unlisted", "Use for plugins" , "all"),
("pluginlist" , "str" , "Plugin list (comma separated)" , "" ),
("revertfailed" , "bool" , "Revert to standard download if fails", True ),
("retry" , "int" , "Number of retries before revert" , 10 ),
@@ -16,9 +16,9 @@ class PremiumTo(MultiHook):
("reload" , "bool" , "Reload plugin list" , True ),
("reloadinterval", "int" , "Reload interval in hours" , 12 )]
- __description = """Premium.to hook plugin"""
- __license = "GPLv3"
- __authors = [("RaNaN", "RaNaN@pyload.org"),
+ __description__ = """Premium.to hook plugin"""
+ __license__ = "GPLv3"
+ __authors__ = [("RaNaN", "RaNaN@pyload.org"),
("zoidberg", "zoidberg@mujmail.cz"),
("stickell", "l.stickell@yahoo.it")]
diff --git a/pyload/plugin/hook/PremiumizeMe.py b/pyload/plugin/hook/PremiumizeMe.py
index a293ca84d..c5f1588ec 100644
--- a/pyload/plugin/hook/PremiumizeMe.py
+++ b/pyload/plugin/hook/PremiumizeMe.py
@@ -5,11 +5,11 @@ from pyload.plugin.internal.MultiHook import MultiHook
class PremiumizeMe(MultiHook):
- __name = "PremiumizeMe"
- __type = "hook"
- __version = "0.17"
+ __name__ = "PremiumizeMe"
+ __type__ = "hook"
+ __version__ = "0.17"
- __config = [("pluginmode" , "all;listed;unlisted", "Use for plugins" , "all"),
+ __config__ = [("pluginmode" , "all;listed;unlisted", "Use for plugins" , "all"),
("pluginlist" , "str" , "Plugin list (comma separated)" , "" ),
("revertfailed" , "bool" , "Revert to standard download if fails", True ),
("retry" , "int" , "Number of retries before revert" , 10 ),
@@ -17,9 +17,9 @@ class PremiumizeMe(MultiHook):
("reload" , "bool" , "Reload plugin list" , True ),
("reloadinterval", "int" , "Reload interval in hours" , 12 )]
- __description = """Premiumize.me hook plugin"""
- __license = "GPLv3"
- __authors = [("Florian Franzen", "FlorianFranzen@gmail.com")]
+ __description__ = """Premiumize.me hook plugin"""
+ __license__ = "GPLv3"
+ __authors__ = [("Florian Franzen", "FlorianFranzen@gmail.com")]
def getHosters(self):
diff --git a/pyload/plugin/hook/PutdriveCom.py b/pyload/plugin/hook/PutdriveCom.py
index 126eb86e8..85e2f541d 100644
--- a/pyload/plugin/hook/PutdriveCom.py
+++ b/pyload/plugin/hook/PutdriveCom.py
@@ -4,15 +4,15 @@ from pyload.plugin.hook.ZeveraCom import ZeveraCom
class PutdriveCom(ZeveraCom):
- __name = "PutdriveCom"
- __type = "hook"
- __version = "0.01"
+ __name__ = "PutdriveCom"
+ __type__ = "hook"
+ __version__ = "0.01"
- __config = [("mode" , "all;listed;unlisted", "Use for plugins (if supported)" , "all"),
+ __config__ = [("mode" , "all;listed;unlisted", "Use for plugins (if supported)" , "all"),
("pluginlist" , "str" , "Plugin list (comma separated)" , "" ),
("revertfailed", "bool" , "Revert to standard download if download fails", False),
("interval" , "int" , "Reload interval in hours (0 to disable)" , 12 )]
- __description = """Putdrive.com hook plugin"""
- __license = "GPLv3"
- __authors = [("Walter Purcaro", "vuolter@gmail.com")]
+ __description__ = """Putdrive.com hook plugin"""
+ __license__ = "GPLv3"
+ __authors__ = [("Walter Purcaro", "vuolter@gmail.com")]
diff --git a/pyload/plugin/hook/RPNetBiz.py b/pyload/plugin/hook/RPNetBiz.py
index 8bfc45df3..75fe0e39b 100644
--- a/pyload/plugin/hook/RPNetBiz.py
+++ b/pyload/plugin/hook/RPNetBiz.py
@@ -5,11 +5,11 @@ from pyload.plugin.internal.MultiHook import MultiHook
class RPNetBiz(MultiHook):
- __name = "RPNetBiz"
- __type = "hook"
- __version = "0.14"
+ __name__ = "RPNetBiz"
+ __type__ = "hook"
+ __version__ = "0.14"
- __config = [("pluginmode" , "all;listed;unlisted", "Use for plugins" , "all"),
+ __config__ = [("pluginmode" , "all;listed;unlisted", "Use for plugins" , "all"),
("pluginlist" , "str" , "Plugin list (comma separated)" , "" ),
("revertfailed" , "bool" , "Revert to standard download if fails", True ),
("retry" , "int" , "Number of retries before revert" , 10 ),
@@ -17,9 +17,9 @@ class RPNetBiz(MultiHook):
("reload" , "bool" , "Reload plugin list" , True ),
("reloadinterval", "int" , "Reload interval in hours" , 12 )]
- __description = """RPNet.biz hook plugin"""
- __license = "GPLv3"
- __authors = [("Dman", "dmanugm@gmail.com")]
+ __description__ = """RPNet.biz hook plugin"""
+ __license__ = "GPLv3"
+ __authors__ = [("Dman", "dmanugm@gmail.com")]
def getHosters(self):
diff --git a/pyload/plugin/hook/RapideoPl.py b/pyload/plugin/hook/RapideoPl.py
index 875f51938..12d53830b 100644
--- a/pyload/plugin/hook/RapideoPl.py
+++ b/pyload/plugin/hook/RapideoPl.py
@@ -5,11 +5,11 @@ from pyload.plugin.internal.MultiHook import MultiHook
class RapideoPl(MultiHook):
- __name = "RapideoPl"
- __type = "hook"
- __version = "0.03"
+ __name__ = "RapideoPl"
+ __type__ = "hook"
+ __version__ = "0.03"
- __config = [("pluginmode" , "all;listed;unlisted", "Use for plugins" , "all"),
+ __config__ = [("pluginmode" , "all;listed;unlisted", "Use for plugins" , "all"),
("pluginlist" , "str" , "Plugin list (comma separated)" , "" ),
("revertfailed" , "bool" , "Revert to standard download if fails", True ),
("retry" , "int" , "Number of retries before revert" , 10 ),
@@ -17,9 +17,9 @@ class RapideoPl(MultiHook):
("reload" , "bool" , "Reload plugin list" , True ),
("reloadinterval", "int" , "Reload interval in hours" , 12 )]
- __description = """Rapideo.pl hook plugin"""
- __license = "GPLv3"
- __authors = [("goddie", "dev@rapideo.pl")]
+ __description__ = """Rapideo.pl hook plugin"""
+ __license__ = "GPLv3"
+ __authors__ = [("goddie", "dev@rapideo.pl")]
def getHosters(self):
diff --git a/pyload/plugin/hook/RealdebridCom.py b/pyload/plugin/hook/RealdebridCom.py
index 681aa1625..a8eb03f83 100644
--- a/pyload/plugin/hook/RealdebridCom.py
+++ b/pyload/plugin/hook/RealdebridCom.py
@@ -4,11 +4,11 @@ from pyload.plugin.internal.MultiHook import MultiHook
class RealdebridCom(MultiHook):
- __name = "RealdebridCom"
- __type = "hook"
- __version = "0.46"
+ __name__ = "RealdebridCom"
+ __type__ = "hook"
+ __version__ = "0.46"
- __config = [("pluginmode" , "all;listed;unlisted", "Use for plugins" , "all"),
+ __config__ = [("pluginmode" , "all;listed;unlisted", "Use for plugins" , "all"),
("pluginlist" , "str" , "Plugin list (comma separated)" , "" ),
("revertfailed" , "bool" , "Revert to standard download if fails", True ),
("retry" , "int" , "Number of retries before revert" , 10 ),
@@ -17,9 +17,9 @@ class RealdebridCom(MultiHook):
("reloadinterval", "int" , "Reload interval in hours" , 12 ),
("ssl" , "bool" , "Use HTTPS" , True )]
- __description = """Real-Debrid.com hook plugin"""
- __license = "GPLv3"
- __authors = [("Devirex Hazzard", "naibaf_11@yahoo.de")]
+ __description__ = """Real-Debrid.com hook plugin"""
+ __license__ = "GPLv3"
+ __authors__ = [("Devirex Hazzard", "naibaf_11@yahoo.de")]
def getHosters(self):
diff --git a/pyload/plugin/hook/RehostTo.py b/pyload/plugin/hook/RehostTo.py
index 95290453b..cda80417c 100644
--- a/pyload/plugin/hook/RehostTo.py
+++ b/pyload/plugin/hook/RehostTo.py
@@ -4,11 +4,11 @@ from pyload.plugin.internal.MultiHook import MultiHook
class RehostTo(MultiHook):
- __name = "RehostTo"
- __type = "hook"
- __version = "0.50"
+ __name__ = "RehostTo"
+ __type__ = "hook"
+ __version__ = "0.50"
- __config = [("pluginmode" , "all;listed;unlisted", "Use for plugins" , "all"),
+ __config__ = [("pluginmode" , "all;listed;unlisted", "Use for plugins" , "all"),
("pluginlist" , "str" , "Plugin list (comma separated)" , "" ),
("revertfailed" , "bool" , "Revert to standard download if fails", True ),
("retry" , "int" , "Number of retries before revert" , 10 ),
@@ -16,9 +16,9 @@ class RehostTo(MultiHook):
("reload" , "bool" , "Reload plugin list" , True ),
("reloadinterval", "int" , "Reload interval in hours" , 12 )]
- __description = """Rehost.to hook plugin"""
- __license = "GPLv3"
- __authors = [("RaNaN", "RaNaN@pyload.org")]
+ __description__ = """Rehost.to hook plugin"""
+ __license__ = "GPLv3"
+ __authors__ = [("RaNaN", "RaNaN@pyload.org")]
def getHosters(self):
diff --git a/pyload/plugin/hook/SimplyPremiumCom.py b/pyload/plugin/hook/SimplyPremiumCom.py
index 3ae6238f4..28d9af41f 100644
--- a/pyload/plugin/hook/SimplyPremiumCom.py
+++ b/pyload/plugin/hook/SimplyPremiumCom.py
@@ -5,11 +5,11 @@ from pyload.plugin.internal.MultiHook import MultiHook
class SimplyPremiumCom(MultiHook):
- __name = "SimplyPremiumCom"
- __type = "hook"
- __version = "0.05"
+ __name__ = "SimplyPremiumCom"
+ __type__ = "hook"
+ __version__ = "0.05"
- __config = [("pluginmode" , "all;listed;unlisted", "Use for plugins" , "all"),
+ __config__ = [("pluginmode" , "all;listed;unlisted", "Use for plugins" , "all"),
("pluginlist" , "str" , "Plugin list (comma separated)" , "" ),
("revertfailed" , "bool" , "Revert to standard download if fails", True ),
("retry" , "int" , "Number of retries before revert" , 10 ),
@@ -17,9 +17,9 @@ class SimplyPremiumCom(MultiHook):
("reload" , "bool" , "Reload plugin list" , True ),
("reloadinterval", "int" , "Reload interval in hours" , 12 )]
- __description = """Simply-Premium.com hook plugin"""
- __license = "GPLv3"
- __authors = [("EvolutionClip", "evolutionclip@live.de")]
+ __description__ = """Simply-Premium.com hook plugin"""
+ __license__ = "GPLv3"
+ __authors__ = [("EvolutionClip", "evolutionclip@live.de")]
def getHosters(self):
diff --git a/pyload/plugin/hook/SimplydebridCom.py b/pyload/plugin/hook/SimplydebridCom.py
index ca2e8f957..011b346b8 100644
--- a/pyload/plugin/hook/SimplydebridCom.py
+++ b/pyload/plugin/hook/SimplydebridCom.py
@@ -4,11 +4,11 @@ from pyload.plugin.internal.MultiHook import MultiHook
class SimplydebridCom(MultiHook):
- __name = "SimplydebridCom"
- __type = "hook"
- __version = "0.04"
+ __name__ = "SimplydebridCom"
+ __type__ = "hook"
+ __version__ = "0.04"
- __config = [("pluginmode" , "all;listed;unlisted", "Use for plugins" , "all"),
+ __config__ = [("pluginmode" , "all;listed;unlisted", "Use for plugins" , "all"),
("pluginlist" , "str" , "Plugin list (comma separated)" , "" ),
("revertfailed" , "bool" , "Revert to standard download if fails", True ),
("retry" , "int" , "Number of retries before revert" , 10 ),
@@ -16,9 +16,9 @@ class SimplydebridCom(MultiHook):
("reload" , "bool" , "Reload plugin list" , True ),
("reloadinterval", "int" , "Reload interval in hours" , 12 )]
- __description = """Simply-Debrid.com hook plugin"""
- __license = "GPLv3"
- __authors = [("Kagenoshin", "kagenoshin@gmx.ch")]
+ __description__ = """Simply-Debrid.com hook plugin"""
+ __license__ = "GPLv3"
+ __authors__ = [("Kagenoshin", "kagenoshin@gmx.ch")]
def getHosters(self):
diff --git a/pyload/plugin/hook/SmoozedCom.py b/pyload/plugin/hook/SmoozedCom.py
index 5e83bb349..3f5aab63d 100644
--- a/pyload/plugin/hook/SmoozedCom.py
+++ b/pyload/plugin/hook/SmoozedCom.py
@@ -4,11 +4,11 @@ from pyload.plugin.internal.MultiHook import MultiHook
class SmoozedCom(MultiHook):
- __name = "SmoozedCom"
- __type = "hook"
- __version = "0.03"
+ __name__ = "SmoozedCom"
+ __type__ = "hook"
+ __version__ = "0.03"
- __config = [("pluginmode" , "all;listed;unlisted", "Use for plugins" , "all"),
+ __config__ = [("pluginmode" , "all;listed;unlisted", "Use for plugins" , "all"),
("pluginlist" , "str" , "Plugin list (comma separated)" , "" ),
("revertfailed" , "bool" , "Revert to standard download if fails", True ),
("retry" , "int" , "Number of retries before revert" , 10 ),
@@ -16,9 +16,9 @@ class SmoozedCom(MultiHook):
("reload" , "bool" , "Reload plugin list" , True ),
("reloadinterval", "int" , "Reload interval in hours" , 12 )]
- __description = """Smoozed.com hook plugin"""
- __license = "GPLv3"
- __authors = [("", "")]
+ __description__ = """Smoozed.com hook plugin"""
+ __license__ = "GPLv3"
+ __authors__ = [("", "")]
def getHosters(self):
diff --git a/pyload/plugin/hook/UnrestrictLi.py b/pyload/plugin/hook/UnrestrictLi.py
index 5ebb61b5a..0c4984042 100644
--- a/pyload/plugin/hook/UnrestrictLi.py
+++ b/pyload/plugin/hook/UnrestrictLi.py
@@ -5,11 +5,11 @@ from pyload.plugin.internal.MultiHook import MultiHook
class UnrestrictLi(MultiHook):
- __name = "UnrestrictLi"
- __type = "hook"
- __version = "0.05"
+ __name__ = "UnrestrictLi"
+ __type__ = "hook"
+ __version__ = "0.05"
- __config = [("pluginmode" , "all;listed;unlisted", "Use for plugins" , "all"),
+ __config__ = [("pluginmode" , "all;listed;unlisted", "Use for plugins" , "all"),
("pluginlist" , "str" , "Plugin list (comma separated)" , "" ),
("revertfailed" , "bool" , "Revert to standard download if fails", True ),
("retry" , "int" , "Number of retries before revert" , 10 ),
@@ -18,9 +18,9 @@ class UnrestrictLi(MultiHook):
("reloadinterval", "int" , "Reload interval in hours" , 12 ),
("history" , "bool" , "Delete History" , False)]
- __description = """Unrestrict.li hook plugin"""
- __license = "GPLv3"
- __authors = [("stickell", "l.stickell@yahoo.it")]
+ __description__ = """Unrestrict.li hook plugin"""
+ __license__ = "GPLv3"
+ __authors__ = [("stickell", "l.stickell@yahoo.it")]
def getHosters(self):
diff --git a/pyload/plugin/hook/ZeveraCom.py b/pyload/plugin/hook/ZeveraCom.py
index 0f0ecec24..a60c33bd4 100644
--- a/pyload/plugin/hook/ZeveraCom.py
+++ b/pyload/plugin/hook/ZeveraCom.py
@@ -4,11 +4,11 @@ from pyload.plugin.internal.MultiHook import MultiHook
class ZeveraCom(MultiHook):
- __name = "ZeveraCom"
- __type = "hook"
- __version = "0.05"
+ __name__ = "ZeveraCom"
+ __type__ = "hook"
+ __version__ = "0.05"
- __config = [("pluginmode" , "all;listed;unlisted", "Use for plugins" , "all"),
+ __config__ = [("pluginmode" , "all;listed;unlisted", "Use for plugins" , "all"),
("pluginlist" , "str" , "Plugin list (comma separated)" , "" ),
("revertfailed" , "bool" , "Revert to standard download if fails", True ),
("retry" , "int" , "Number of retries before revert" , 10 ),
@@ -16,9 +16,9 @@ class ZeveraCom(MultiHook):
("reload" , "bool" , "Reload plugin list" , True ),
("reloadinterval", "int" , "Reload interval in hours" , 12 )]
- __description = """Zevera.com hook plugin"""
- __license = "GPLv3"
- __authors = [("zoidberg", "zoidberg@mujmail.cz"),
+ __description__ = """Zevera.com hook plugin"""
+ __license__ = "GPLv3"
+ __authors__ = [("zoidberg", "zoidberg@mujmail.cz"),
("Walter Purcaro", "vuolter@gmail.com")]
diff --git a/pyload/plugin/hook/XFileSharingPro.py b/pyload/plugin/hook/XFileSharingPro.py
index 653e53d1e..94866566c 100644
--- a/pyload/plugin/hook/XFileSharingPro.py
+++ b/pyload/plugin/hook/XFileSharingPro.py
@@ -6,20 +6,20 @@ from pyload.plugin.Hook import Hook
class XFileSharingPro(Hook):
- __name = "XFileSharingPro"
- __type = "hook"
- __version = "0.32"
+ __name__ = "XFileSharingPro"
+ __type__ = "hook"
+ __version__ = "0.32"
- __config = [("activated" , "bool", "Activated" , True ),
+ __config__ = [("activated" , "bool", "Activated" , True ),
("use_hoster_list" , "bool", "Load listed hosters only" , False),
("use_crypter_list", "bool", "Load listed crypters only" , False),
("use_builtin_list", "bool", "Load built-in plugin list" , True ),
("hoster_list" , "str" , "Hoster list (comma separated)" , "" ),
("crypter_list" , "str" , "Crypter list (comma separated)", "" )]
- __description = """Load XFileSharingPro based hosters and crypter which don't need a own plugin to run"""
- __license = "GPLv3"
- __authors = [("Walter Purcaro", "vuolter@gmail.com")]
+ __description__ = """Load XFileSharingPro based hosters and crypter which don't need a own plugin to run"""
+ __license__ = "GPLv3"
+ __authors__ = [("Walter Purcaro", "vuolter@gmail.com")]
# event_list = ["pluginConfigChanged"]
@@ -41,7 +41,7 @@ class XFileSharingPro(Hook):
CRYPTER_BUILTIN = ["junocloud.me", "rapidfileshare.net"]
# def pluginConfigChanged(self.__name, plugin, name, value):
# self.loadPattern()
@@ -41,7 +41,7 @@ class XFileSharingPro(Hook):
CRYPTER_BUILTIN = ["junocloud.me", "rapidfileshare.net"]
- # def pluginConfigChanged(self.__name, plugin, name, value):
+ # def pluginConfigChanged(self.__name__, plugin, name, value):
# self.loadPattern()